



rsvg-convert.exe --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\rsvg-2.0-vs16.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=exec_prefix --dont-define-prefix librsvg-2.0`) do if not exist "%%a/bin/rsvg-2.0-vs16.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\rsvg-2.0.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`pkg-config --variable=libdir --dont-define-prefix librsvg-2.0`) do if not exist "%%a/rsvg-2.0.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gdk-pixbuf-2.0\\2.10.0\\loaders\\libpixbufloader-svg.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\librsvg-2.0\\librsvg\\rsvg-features.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\librsvg-2.0\\librsvg\\rsvg-cairo.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\librsvg-2.0\\librsvg\\rsvg.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
